==> chaosmesh-model-5.0.1-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/StressChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface StressChaosListFluent<A extends StressChaosListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,StressChaos item);
    public A setToItems(int index,StressChaos item);
    public A addToItems(StressChaos... items);
    public A addAllToItems(Collection<StressChaos> items);
    public A removeFromItems(StressChaos... items);
    public A removeAllFromItems(Collection<StressChaos> items);
    public A removeMatchingFromItems(Predicate<StressChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<StressChaos> getItems();
    public List<StressChaos> buildItems();
    public StressChaos buildItem(int index);
    public StressChaos buildFirstItem();
    public StressChaos buildLastItem();
    public StressChaos buildMatchingItem(Predicate<StressChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<StressChaosBuilder> predicate);
    public A withItems(List<StressChaos> items);
    public A withItems(StressChaos... items);
    public Boolean hasItems();
    public StressChaosListFluent.ItemsNested<A> addNewItem();
    public StressChaosListFluent.ItemsNested<A> addNewItemLike(StressChaos item);
    public StressChaosListFluent.ItemsNested<A> setNewItemLike(int index,StressChaos item);
    public StressChaosListFluent.ItemsNested<A> editItem(int index);
    public StressChaosListFluent.ItemsNested<A> editFirstItem();
    public StressChaosListFluent.ItemsNested<A> editLastItem();
    public StressChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<StressChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StressChaosFluent<StressChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/StressChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface StressChaosListFluent<A extends StressChaosListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,StressChaos item);
    public A setToItems(int index,StressChaos item);
    public A addToItems(StressChaos... items);
    public A addAllToItems(Collection<StressChaos> items);
    public A removeFromItems(StressChaos... items);
    public A removeAllFromItems(Collection<StressChaos> items);
    public A removeMatchingFromItems(Predicate<StressChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<StressChaos> getItems();
    public List<StressChaos> buildItems();
    public StressChaos buildItem(int index);
    public StressChaos buildFirstItem();
    public StressChaos buildLastItem();
    public StressChaos buildMatchingItem(Predicate<StressChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<StressChaosBuilder> predicate);
    public A withItems(List<StressChaos> items);
    public A withItems(StressChaos... items);
    public Boolean hasItems();
    public StressChaosListFluent.ItemsNested<A> addNewItem();
    public StressChaosListFluent.ItemsNested<A> addNewItemLike(StressChaos item);
    public StressChaosListFluent.ItemsNested<A> setNewItemLike(int index,StressChaos item);
    public StressChaosListFluent.ItemsNested<A> editItem(int index);
    public StressChaosListFluent.ItemsNested<A> editFirstItem();
    public StressChaosListFluent.ItemsNested<A> editLastItem();
    public StressChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<StressChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StressChaosFluent<StressChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
